==> pluxml_5.4.orig.tar.gz: PluXml-5.4/core/lang/en/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'English',

# common
'L_PLUXML_VERSION'				=> 'PluXml version',
'L_HOMEPAGE'					=> 'Homepage',
'L_UNCLASSIFIED'				=> 'Uncategorized',
'L_INFO_PHP_VERSION'			=> 'PHP version',
'L_INFO_MAGIC_QUOTES'			=> 'State of "magic quotes"',
'L_INFO_CHARSET'				=> 'charset',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'Main PluXml theme not found',
'L_ERR_FILE_NOTFOUND'			=> 'PluXml target file not found',
'L_ERR_PAGE_NOT_FOUND'			=> 'Page not found',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'jan',
'L_SHORT_FEBRUARY'				=> 'feb',
'L_SHORT_MARCH'					=> 'mar',
'L_SHORT_APRIL'					=> 'apr',
'L_SHORT_MAY'					=> 'may',
'L_SHORT_JUNE'					=> 'june',
'L_SHORT_JULY'					=> 'july',
'L_SHORT_AUGUST'				=> 'aug',
'L_SHORT_SEPTEMBER'				=> 'sept',
'L_SHORT_OCTOBER'				=> 'oct',
'L_SHORT_NOVEMBER'				=> 'nov',
'L_SHORT_DECEMBER'				=> 'dec',
'L_JANUARY'						=> 'january',
'L_FEBRUARY'					=> 'february',
'L_MARCH'						=> 'march',
'L_APRIL'						=> 'april',
'L_MAY'							=> 'may',
'L_JUNE'						=> 'june',
'L_JULY'						=> 'july',
'L_AUGUST'						=> 'august',
'L_SEPTEMBER'					=> 'september',
'L_OCTOBER'						=> 'october',
'L_NOVEMBER'					=> 'november',
'L_DECEMBER'					=> 'december',
'L_MONDAY'						=> 'monday',
'L_TUESDAY'						=> 'tuesday',
'L_WEDNESDAY'					=> 'wednesday',
'L_THURSDAY'					=> 'thursday',
'L_FRIDAY'						=> 'friday',
'L_SATURDAY'					=> 'saturday',
'L_SUNDAY'						=> 'sunday',

# class.plx.capcha.php
'L_LAST'						=> 'last',
'L_FIRST'						=> 'first',
'L_SECOND'						=> 'second',
'L_THIRD'						=> 'third',
'L_FOURTH'						=> 'fourth',
'L_FIFTH'						=> 'fifth',
'L_SIXTH'						=> 'sixth',
'L_SEVENTH'						=> 'seventh',
'L_EIGTH'						=> 'eighth',
'L_NINTH'						=> 'ninth',
'L_TENTH'						=> 'tenth',
'L_NTH'							=> 'nth',
'L_CAPCHA_QUESTION'				=> 'What is the <span class="capcha-letter">%s</span> letter of the word <span class="capcha-word">%s</span>?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s has write access',
'L_WRITE_NOT_ACCESS'			=> '%s does not have write access or does not exist',
'L_MODREWRITE_AVAILABLE'		=> 'Apache URL Rewriting module mod_rewrite available',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Apache URL Rewriting module mod_rewrite unavailable',
'L_LIBGD_INSTALLED'				=> 'GD library installed',
'L_LIBGD_NOT_INSTALLED'			=> 'GD library not installed',
'L_MAIL_AVAILABLE'				=> 'Mail sending function available',
'L_MAIL_NOT_AVAILABLE'			=> 'Mail sending function unavailable',

# class.plx.motor.php
'L_FILE_VERSION_REQUIRED'		=> 'File "%sversion" is required by PluXml',
'L_ARTICLE_NO_TAG'				=> 'No article has been found for this tag!',
'L_UNKNOWN_CATEGORY'			=> 'This category does not exist!!',
'L_NO_ARTICLE_PAGE'				=> 'No article has been found for this page!',
'L_UNKNOWN_ARTICLE'				=> 'This article does not exist or does not exist anymore!',
'L_COM_IN_MODERATION'			=> 'The comment is being reviewed by this site\'s administrator',
'L_UNKNOWN_STATIC'				=> 'This page does not exist or does not exist anymore!',
'L_DOCUMENT_NOT_FOUND'			=> 'Document not found',
'L_NEWCOMMENT_ERR'				=> 'An error occurred during comment\'s publication',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Please fill all the required fields',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'Antispam verification failed',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Compression %s activated',
'L_PAGETITLE_ARCHIVES'			=> 'Archives',
'L_PAGETITLE_TAG'				=> 'Tag',
'L_NO_CATEGORY'					=> 'no categorie',
'L_CATEGORY'					=> 'category',
'L_CATEGORIES'					=> 'categories',
'L_NO_ARTICLE'					=> 'no article',
'L_ARTICLE'						=> 'article',
'L_ARTICLES'					=> 'articles',
'L_ARTAUTHOR_UNKNOWN'			=> 'unknown',
'L_ARTTAGS_NONE'				=> 'none',
'L_ARTCHAPO'					=> 'Read more #art_title',
'L_ARTFEED_RSS_CATEGORY'		=> 'Rss feed of the category',
'L_ARTFEED_RSS_TAG'				=> 'Rss feed of the tag',
'L_ARTFEED_RSS'					=> 'Rss feed of the articles',
'L_NO_COMMENT'					=> 'no comments',
'L_COMMENT'						=> 'comment',
'L_COMMENTS'					=> 'comments',
'L_COMFEED_RSS_ARTICLE'			=> 'Rss feed of the article\'s comments',
'L_COMFEED_RSS'					=> 'Rss feed of comments',
'L_STATICCONTENT_INPROCESS'		=> 'This page is currently being edited',
'L_SAID'						=> 'said',

'L_PAGINATION_FIRST_TITLE'		=> 'Go to first page',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Previous page',
'L_PAGINATION_PREVIOUS'			=> 'previous',
'L_PAGINATION_NEXT_TITLE'		=> 'Next page',
'L_PAGINATION_NEXT'				=> 'next',
'L_PAGINATION_LAST_TITLE'		=> 'Go to last page',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'page %s of %s',

'L_PAGEBLOG_TITLE'				=> 'Blog',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'Private URLs have not been initialized in your administration settings!',
'L_FEED_COMMENTS'				=> 'Comments',
'L_FEED_ONLINE_COMMENTS'		=> 'Online comments',
'L_FEED_OFFLINE_COMMENTS'		=> 'Offline comments',
'L_FEED_WRITTEN_BY'				=> 'Written by',

);
?>

==> pluxml_5.5.orig.tar.gz: PluXml-5.5/core/lang/en/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'English',

'L_DATE_CREATION'				=> 'Creation date',
'L_DATE_UPDATE'					=> 'Date updated',

# common
'L_PLUXML_VERSION'				=> 'PluXml version',
'L_HOMEPAGE'					=> 'Homepage',
'L_UNCLASSIFIED'				=> 'Uncategorized',
'L_INFO_PHP_VERSION'			=> 'PHP version',
'L_INFO_MAGIC_QUOTES'			=> 'State of "magic quotes"',
'L_INFO_CHARSET'				=> 'charset',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'Main PluXml theme not found',
'L_ERR_FILE_NOTFOUND'			=> 'PluXml target file not found',
'L_ERR_PAGE_NOT_FOUND'			=> 'Page not found',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'jan',
'L_SHORT_FEBRUARY'				=> 'feb',
'L_SHORT_MARCH'					=> 'mar',
'L_SHORT_APRIL'					=> 'apr',
'L_SHORT_MAY'					=> 'may',
'L_SHORT_JUNE'					=> 'june',
'L_SHORT_JULY'					=> 'july',
'L_SHORT_AUGUST'				=> 'aug',
'L_SHORT_SEPTEMBER'				=> 'sept',
'L_SHORT_OCTOBER'				=> 'oct',
'L_SHORT_NOVEMBER'				=> 'nov',
'L_SHORT_DECEMBER'				=> 'dec',
'L_JANUARY'						=> 'january',
'L_FEBRUARY'					=> 'february',
'L_MARCH'						=> 'march',
'L_APRIL'						=> 'april',
'L_MAY'							=> 'may',
'L_JUNE'						=> 'june',
'L_JULY'						=> 'july',
'L_AUGUST'						=> 'august',
'L_SEPTEMBER'					=> 'september',
'L_OCTOBER'						=> 'october',
'L_NOVEMBER'					=> 'november',
'L_DECEMBER'					=> 'december',
'L_MONDAY'						=> 'monday',
'L_TUESDAY'						=> 'tuesday',
'L_WEDNESDAY'					=> 'wednesday',
'L_THURSDAY'					=> 'thursday',
'L_FRIDAY'						=> 'friday',
'L_SATURDAY'					=> 'saturday',
'L_SUNDAY'						=> 'sunday',

# class.plx.capcha.php
'L_LAST'						=> 'last',
'L_FIRST'						=> 'first',
'L_SECOND'						=> 'second',
'L_THIRD'						=> 'third',
'L_FOURTH'						=> 'fourth',
'L_FIFTH'						=> 'fifth',
'L_SIXTH'						=> 'sixth',
'L_SEVENTH'						=> 'seventh',
'L_EIGTH'						=> 'eighth',
'L_NINTH'						=> 'ninth',
'L_TENTH'						=> 'tenth',
'L_NTH'							=> 'nth',
'L_CAPCHA_QUESTION'				=> 'What is the <span class="capcha-letter">%s</span> letter of the word <span class="capcha-word">%s</span>?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s has write access',
'L_WRITE_NOT_ACCESS'			=> '%s does not have write access or does not exist',
'L_MODREWRITE_AVAILABLE'		=> 'Apache URL Rewriting module mod_rewrite available',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Apache URL Rewriting module mod_rewrite unavailable',
'L_LIBGD_INSTALLED'				=> 'GD library installed',
'L_LIBGD_NOT_INSTALLED'			=> 'GD library not installed',
'L_MAIL_AVAILABLE'				=> 'Mail sending function available',
'L_MAIL_NOT_AVAILABLE'			=> 'Mail sending function unavailable',

# class.plx.motor.php
'L_ARTICLE_NO_TAG'				=> 'No article has been found for this tag!',
'L_UNKNOWN_CATEGORY'			=> 'This category does not exist!!',
'L_NO_ARTICLE_PAGE'				=> 'No article has been found for this page!',
'L_UNKNOWN_ARTICLE'				=> 'This article does not exist or does not exist anymore!',
'L_COM_IN_MODERATION'			=> 'The comment is being reviewed by this site\'s administrator',
'L_UNKNOWN_STATIC'				=> 'This page does not exist or does not exist anymore!',
'L_DOCUMENT_NOT_FOUND'			=> 'Document not found',
'L_NEWCOMMENT_ERR'				=> 'An error occurred during comment\'s publication',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Please fill all the required fields',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'Antispam verification failed',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Compression %s activated',
'L_PAGETITLE_ARCHIVES'			=> 'Archives',
'L_PAGETITLE_TAG'				=> 'Tag',
'L_NO_CATEGORY'					=> 'no categorie',
'L_CATEGORY'					=> 'category',
'L_CATEGORIES'					=> 'categories',
'L_NO_ARTICLE'					=> 'no article',
'L_ARTICLE'						=> 'article',
'L_ARTICLES'					=> 'articles',
'L_ARTAUTHOR_UNKNOWN'			=> 'unknown',
'L_ARTTAGS_NONE'				=> 'none',
'L_ARTCHAPO'					=> 'Read more #art_title',
'L_ARTFEED_RSS_CATEGORY'		=> 'Rss feed of the category',
'L_ARTFEED_RSS_TAG'				=> 'Rss feed of the tag',
'L_ARTFEED_RSS'					=> 'Rss feed of the articles',
'L_NO_COMMENT'					=> 'no comments',
'L_COMMENT'						=> 'comment',
'L_COMMENTS'					=> 'comments',
'L_COMFEED_RSS_ARTICLE'			=> 'Rss feed of the article\'s comments',
'L_COMFEED_RSS'					=> 'Rss feed of comments',
'L_STATICCONTENT_INPROCESS'		=> 'This page is currently being edited',
'L_SAID'						=> 'said',

'L_PAGINATION_FIRST_TITLE'		=> 'Go to first page',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Previous page',
'L_PAGINATION_PREVIOUS'			=> 'previous',
'L_PAGINATION_NEXT_TITLE'		=> 'Next page',
'L_PAGINATION_NEXT'				=> 'next',
'L_PAGINATION_LAST_TITLE'		=> 'Go to last page',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'page %s of %s',

'L_PAGEBLOG_TITLE'				=> 'Blog',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'Private URLs have not been initialized in your administration settings!',
'L_FEED_COMMENTS'				=> 'Comments',
'L_FEED_ONLINE_COMMENTS'		=> 'Online comments',
'L_FEED_OFFLINE_COMMENTS'		=> 'Offline comments',
'L_FEED_WRITTEN_BY'				=> 'Written by',

);
?>
